<?php

/*
Plugin Name: KCR Simple Tweet
Version: .097
Plugin URI: http://www.knightdale-computer-repair.com/coding/displaying-your-twitter-timeline/
Description: A quick method of displaying tweets from a twitter timeline. Uses twitteroauth to handle getting tweets from a user_timeline. Use the shortcode: [kcr_display_tweet] , as well as several options.
Author: John
Author URI: http://www.kcrnc.com

*/

include_once('twitteroauth/twitteroauth.php');

add_shortcode( 'kcr_display_tweet', 'kcr_st_display_tweet');

function kcr_st_display_tweet($args){
	
	$defaults = array(
	      'css_id'=>'kcr_st_tweets_holder',
	      'css_class'=>'kcr_st_tweets',
	      'error_message'=>'No Twitter messages found for {USER_NAME}.',
	      'number_tweets'=>'-1',
	      'hyperlink'=>'1',
	      'hyperlink_users'=>'1',
	      'link_to_tweet'=>'1',
	      );
	      
	$args = wp_parse_args( $args, $defaults );	
	$available_options = get_option('kcr_st_options');

	$twitter_handle = $available_options['kcr_st_twitter_handle']['value'];
	$time_format = $available_options['kcr_st_time_format']['value'];
	$consumer_key = $available_options['kcr_st_twitter_consumer_key']['value'];
	$consumer_secret = $available_options['kcr_st_twitter_consumer_secret']['value'];	
	$oauth_token = $available_options['kcr_st_twitter_oauth_token']['value'];	
	$oauth_secret = $available_options['kcr_st_twitter_oauth_token_secret']['value'];	
	$include_retweets = $available_options['kcr_st_twitter_include_rts']['value'];
		
   
    
	if($args['number_of_tweets'] == -1 || intval($args['number_of_tweets']) <= 0)
		$number_of_tweets = intval($available_options['kcr_st_number_tweets']);
	
	if($include_retweets != '1')
		$include_retweets = false;
	else
		$include_retweets = true;		
	
    $tweet_link_base = "https://twitter.com/{USER_NAME}/status/";  
    $tweet_body = "<ul id='{$args['css_id']}' class='{$args['css_class']}'>";
    
    if(empty($twitter_handle)){
		
		$tweet_body .= "<li>Invalid Twitter Username Selected<a href='' class='kcr_st_link'></a></li></ul>";		
		return $tweet_body;		
		
	} else {
		
		$tweet_link_base = str_replace('{USER_NAME}', $twitter_handle, $tweet_link_base);	   
    
		$twitter_connection = new TwitterOAuth($consumer_key, $consumer_secret,$oauth_token, $oauth_secret );
		
		$retrieved_tweets = $twitter_connection->get('statuses/user_timeline', array('count'=>$number_of_tweets, 'include_rts'=>$include_retweets));    
		
		
	}   

    
    if(!is_array($retrieved_tweets) || count($retrieved_tweets) <= 0){
		
		$tweet_body .= "<li>".str_replace('{USER_NAME}', $twitter_handle, $args['error_message']) ."</li>";
		
		$retrieved_tweets = array();
		
		}


			foreach ( $retrieved_tweets as $tweet_index => $tweet ) {

                        $tweet_text = $tweet->text;
                        $tweet_link = $tweet_link_base.$tweet->id;
                        
                        if($time_format != -1)
							$tweet_time = " - ".date($time_format, strtotime($tweet->created_at));
						else
							$tweet_time = '';

                        $tweet_body .=  '<li id="kcr_st_tweet_{$tweet_index}">';

                        if ($args['hyperlink'] == '1')
                            $tweet_text = kcr_st_add_hyperlinks($tweet_text); 

                        if ($args['hyperlink_users'] == '1')
                            $tweet_text = kcr_st_parse_users($tweet_text);

						if($args['link_to_tweet'] == '1')
							 $tweet_text .= '<a href="'.$tweet_link.'" class="kcr_st_link"></a>';

					$tweet_body.="{$tweet_text}{$tweet_time}</li>";
					
                  }


						


	$tweet_body.= '</ul>';


	return $tweet_body;
	
     
}

add_action('admin_print_styles', 'kcr_st_user_styles');
add_action('wp_print_styles', 'kcr_st_user_styles');

function kcr_st_user_styles() {

        if(empty($_SERVER['HTTPS']))
           $plugin_url = WP_PLUGIN_URL;
         else
           $plugin_url = str_replace('http:', 'https:', WP_PLUGIN_URL);

        wp_register_style( 'kcr-st-style', $plugin_url.'/kcr-simple-tweet/css/kcr_simple_tweet.css', true);
        wp_enqueue_style( 'kcr-st-style' );
        
}


add_action("admin_menu", 'kcr_st_add_option_page');

function kcr_st_add_option_page(){
require_once('kcr_admin_settings.php');
	add_menu_page('Tweets', 'Tweets', 'manage_options', 'kcr_st_display_options', 'kcr_st_display_options', '');	
}


// Link discover stuff

function kcr_st_add_hyperlinks($text) {
    // Props to Allen Shaw & webmancers.com
    // match protocol://address/path/file.extension?some=variable&another=asf%
    //$text = preg_replace("/\b([a-zA-Z]+:\/\/[a-z][a-z0-9\_\.\-]*[a-z]{2,6}[a-zA-Z0-9\/\*\-\?\&\%]*)\b/i","<a href=\"$1\" class=\"twitter-link\">$1</a>", $text);
    $text = preg_replace('/\b([a-zA-Z]+:\/\/[\w_.\-]+\.[a-zA-Z]{2,6}[\/\w\-~.?=&%#+$*!]*)\b/i',"<a href=\"$1\" class=\"twitter-link\">$1</a>", $text);
    // match www.something.domain/path/file.extension?some=variable&another=asf%
    //$text = preg_replace("/\b(www\.[a-z][a-z0-9\_\.\-]*[a-z]{2,6}[a-zA-Z0-9\/\*\-\?\&\%]*)\b/i","<a href=\"http://$1\" class=\"twitter-link\">$1</a>", $text);
    $text = preg_replace('/\b(?<!:\/\/)(www\.[\w_.\-]+\.[a-zA-Z]{2,6}[\/\w\-~.?=&%#+$*!]*)\b/i',"<a href=\"http://$1\" class=\"twitter-link\">$1</a>", $text);    
    
    // match name@address
    $text = preg_replace("/\b([a-zA-Z][a-zA-Z0-9\_\.\-]*[a-zA-Z]*\@[a-zA-Z][a-zA-Z0-9\_\.\-]*[a-zA-Z]{2,6})\b/i","<a href=\"mailto://$1\" class=\"twitter-link\">$1</a>", $text);
        //mach #trendingtopics. Props to Michael Voigt
    $text = preg_replace('/([\.|\,|\:|\�|\�|\>|\{|\(]?)#{1}(\w*)([\.|\,|\:|\!|\?|\>|\}|\)]?)\s/i', "$1<a href=\"http://twitter.com/#search?q=$2\" class=\"twitter-link\">#$2</a>$3 ", $text);
    return $text;
}

function kcr_st_parse_users($text) {
       $text = preg_replace('/([\.|\,|\:|\�|\�|\>|\{|\(]?)@{1}(\w*)([\.|\,|\:|\!|\?|\>|\}|\)]?)\s/i', "$1<a href=\"http://twitter.com/$2\" class=\"twitter-user\">@$2</a>$3 ", $text);
       return $text;
}     


?>
